@@ -20,7 +20,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: ActionManager.java 4310 2009-07-07 14:41:06Z chahinem $
+ * $Id: ActionManager.java 5343 2009-09-17 23:22:48Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jasmine.jadort.service.implementation;
@@ -84,9 +84,9 @@ public class ActionManager extends OperationPersistenceManager {
                         if (aimedServerProgressState.equals(ServerProgressState.STOP_OK)) {
                             // next
                             if (serverProgress.getServer().getVm() != null) {
-                                JMSSender.stopVM(this.operation, serverProgress, serverProgress.getOldDeploymentItem());
+                                JMSSender.stopVM(this.operation, serverProgress, false, serverProgress.getOldDeploymentItem());
                             } else {
-                                JMSSender.stopServer(this.operation, serverProgress);
+                                JMSSender.stopServer(this.operation, serverProgress, false);
                             }
                             return;
                         }
@@ -103,9 +103,9 @@ public class ActionManager extends OperationPersistenceManager {
                     if (aimedServerProgressState.equals(ServerProgressState.STOP_OK)) {
                         // next
                         if (serverProgress.getServer().getVm() != null) {
-                            JMSSender.stopVM(this.operation, serverProgress, serverProgress.getOldDeploymentItem());
+                            JMSSender.stopVM(this.operation, serverProgress, false, serverProgress.getOldDeploymentItem());
                         } else {
-                            JMSSender.stopServer(this.operation, serverProgress);
+                            JMSSender.stopServer(this.operation, serverProgress, false);
                         }
                         return;
                     } else if (aimedServerProgressState.equals(ServerProgressState.INITIAL)) {
@@ -128,17 +128,17 @@ public class ActionManager extends OperationPersistenceManager {
                     } else if (aimedServerProgressState.equals(ServerProgressState.INITIAL)) {
                         // previous
                         if (serverProgress.getServer().getVm() != null) {
-                            JMSSender.startVM(this.operation, serverProgress, serverProgress.getOldDeploymentItem());
+                            JMSSender.startVM(this.operation, serverProgress, false, serverProgress.getOldDeploymentItem());
                         } else {
-                            JMSSender.startServer(this.operation, serverProgress);
+                            JMSSender.startServer(this.operation, serverProgress, false);
                         }
                         return;
                     } else if (aimedServerProgressState.equals(ServerProgressState.DISABLE_APPLICATIONS_OK)) {
                         // previous
                         if (serverProgress.getServer().getVm() != null) {
-                            JMSSender.startVM(this.operation, serverProgress, serverProgress.getOldDeploymentItem());
+                            JMSSender.startVM(this.operation, serverProgress, false, serverProgress.getOldDeploymentItem());
                         } else {
-                            JMSSender.startServer(this.operation, serverProgress);
+                            JMSSender.startServer(this.operation, serverProgress, false);
                         }
                         return;
                     }
@@ -146,9 +146,9 @@ public class ActionManager extends OperationPersistenceManager {
                     if (aimedServerProgressState.equals(ServerProgressState.START_OK)) {
                         // next
                         if (serverProgress.getServer().getVm() != null) {
-                            JMSSender.startVM(this.operation, serverProgress, serverProgress.getNewDeploymentItem());
+                            JMSSender.startVM(this.operation, serverProgress, true, serverProgress.getNewDeploymentItem());
                         } else {
-                            JMSSender.startServer(this.operation, serverProgress);
+                            JMSSender.startServer(this.operation, serverProgress, true);
                         }
                         return;
                     } else if (aimedServerProgressState.equals(ServerProgressState.STOP_OK)) {
@@ -167,9 +167,9 @@ public class ActionManager extends OperationPersistenceManager {
                     if (aimedServerProgressState.equals(ServerProgressState.MAINTAIN_OK)) {
                         // previous
                         if (serverProgress.getServer().getVm() != null) {
-                            JMSSender.stopVM(this.operation, serverProgress, serverProgress.getNewDeploymentItem());
+                            JMSSender.stopVM(this.operation, serverProgress, true, serverProgress.getNewDeploymentItem());
                         } else {
-                            JMSSender.stopServer(this.operation, serverProgress);
+                            JMSSender.stopServer(this.operation, serverProgress, true);
                         }
                         return;
                     } else if (aimedServerProgressState.equals(ServerProgressState.DESTROY_VM_HOSTS_OK)) {
@@ -443,8 +443,35 @@ public class ActionManager extends OperationPersistenceManager {
                 groupBeanCopy.setName(groupBean.getName());
                 groupBeanCopy.setServers(new ArrayList<ServerBean>(groupBean.getServers()));
                 groupBeanCopy.setClustered(groupBean.getClustered());
-                groupBeanCopy.setConnected(groupBean.getConnected());
                 if (fillApplications) {
+                    if (groupBean.getServers() != null) {
+                        for (ServerBean server : groupBean.getServers()) {
+                            ServerAction serverAction = ServerAction.getServerAction(server);
+                            try {
+                                serverAction.listOfApplications();
+                            } catch (IOException e) {
+                                groupBeanCopy.setConnected(false);
+                            } catch (Exception e) {
+                                String message = e.getClass().getName() + ": " + e.getMessage();
+                                throw new JadortServiceException("Failed getting the applications on the server "
+                                    + server.getName() + ": " + message, e);
+                            }
+                            if (server.getVm() != null) {
+                                VMMAction vmmAction = VMMAction.getVMMAction(server.getVm());
+                                try {
+                                    String fullServerName = vmmAction.getFullVMName(server.getVm().getName());
+                                    vmmAction.getVMState(fullServerName);
+                                } catch (IOException e) {
+                                    groupBeanCopy.setConnected(false);
+                                } catch (Exception e) {
+                                    String message = e.getClass().getName() + ": " + e.getMessage();
+                                    throw new JadortServiceException("Failed getting the state for the VM "
+                                        + server.getVm().getName() + ": " + message, e);
+                                }
+                            }
+                        }
+                    }
+
                     this.fillApplications(groupBeanCopy);
                 }
                 result.add(groupBeanCopy);
